/*
 * Copyright (c) 2015, Majenko Technologies
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 * * Neither the name of Majenko Technologies nor the names of its
 *   contributors may be used to endorse or promote products derived from
 *   this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

// Requires a PRO license for ViSi-Genie Magic to operate.

#include <genieArduino.h>
#include <SoftwareSerial.h>

#define RESETLINE 4  // Change this if you are not using an Arduino Adaptor Shield Version 2 (see code below)

Genie genie;

// Use software serial on pins 10 and 11, which means set the RX and TX jumpers on
// the Arduino breakout board to use D10 and D11.
SoftwareSerial serial(10, 11);

// we will send 4 bytes at a time
const int BYTELENGTH = 4;
byte valueBuffer[BYTELENGTH];

unsigned long int largeValue = 2147480000;

void setup()
{
  Serial.begin(9600);  // Console in Arduino IDE on Serial0
  serial.begin(9600);
  genie.Begin(serial);

  // Reset the Display (change D4 to D2 if you have original 4D Arduino Adaptor)
  // THIS IS IMPORTANT AND CAN PREVENT OUT OF SYNC ISSUES, SLOW SPEED RESPONSE ETC
  // If NOT using a 4D Arduino Adaptor, digitalWrites must be reversed as Display Reset is Active Low, and
  // the 4D Arduino Adaptors invert this signal so must be Active High.
  pinMode(RESETLINE, OUTPUT);  // Set D4 on Arduino to Output (4D Arduino Adaptor V2 - Display Reset)
  digitalWrite(RESETLINE, 1);  // Reset the Display via D4
  delay(100);
  digitalWrite(RESETLINE, 0);  // unReset the Display via D4

  delay (5000); //let the display start up after the reset (This is important)
}

void loop(){
  // send the 32-bit integer, byte-by-byte
  valueBuffer[0] = largeValue >> 24;
  valueBuffer[1] = largeValue >> 16;
  valueBuffer[2] = largeValue >> 8;
  valueBuffer[3] = largeValue;
  
  // Send it to MagicObject0
  genie.WriteMagicBytes(0, valueBuffer, BYTELENGTH);
  
  // Send it to MagicObject1
  genie.WriteMagicBytes(1, valueBuffer, BYTELENGTH);
  
  Serial.print("value: ");
  Serial.println(largeValue);
  Serial.print("bytes sent: ");
  Serial.print(valueBuffer[0], HEX);
  Serial.print(" ");  
  Serial.print(valueBuffer[1], HEX);
  Serial.print(" ");  
  Serial.print(valueBuffer[2], HEX);
  Serial.print(" ");  
  Serial.print(valueBuffer[3], HEX);
  Serial.print(" ");  
  Serial.print("\n\n");
  //delay(500);
  
  largeValue += 111;
}


